# msprime

[![Travis](https://img.shields.io/travis/jeromekelleher/msprime/master.svg)](https://travis-ci.org/jeromekelleher/msprime) [![AppVeyor](https://ci.appveyor.com/api/projects/status/7u35hb93h0hmo000/branch/master?svg=true
)](https://ci.appveyor.com/project/jeromekelleher/msprime/branch/master) [![CircleCI](https://circleci.com/gh/jeromekelleher/msprime.svg?style=shield)](https://circleci.com/gh/jeromekelleher/msprime) [![CodeCov](https://img.shields.io/codecov/c/github/jeromekelleher/msprime.svg)](https://codecov.io/gh/jeromekelleher/msprime) [![Read the docs](https://readthedocs.org/projects/msprime/badge/?version=latest)](http://msprime.readthedocs.io/en/latest/?badge=latest) [![Coverity Scan](https://scan.coverity.com/projects/jeromekelleher-msprime/badge.svg)](https://scan.coverity.com/projects/jeromekelleher-msprime)

``msprime`` is a Python API and command line interface for simulating the 
coalescent with recombination. Please see the 
[documentation](https://msprime.readthedocs.org/en/latest/)
for further information and 
[installation instructions](https://msprime.readthedocs.org/en/latest/installation.html).

If you would like to help make ``msprime`` better, please see the 
[developer documentation](https://msprime.readthedocs.org/en/latest/development.html)
to get started.

If you use ``msprime`` in your work, please cite the [PLOS Computational
Biology](http://dx.doi.org/10.1371/journal.pcbi.1004842) paper.
See [here](https://msprime.readthedocs.org/en/latest/CITATION.html) for
full citation details.
